import setuptools


setuptools.setup(
    name="doenova",
    version="0.1.9",
    author="Francis B. Lavoie",
    author_email="francis.b.lavoie@usherbrooke.ca",
    description="Simple DOE and ANOVA package for Python 3",
    long_description="Simple DOE and ANOVA package for Python 3. Please visit [doenova.tripli.ca](http://doenova.tripli.ca) for instructions and demos.",
    long_description_content_type="text/markdown",
    url="http://doenova.tripli.ca/",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ),
)